NtpServer enum

Curated list of public NTP servers.

Inheritance
Available extensions

Values

google → const NtpServer
const NtpServer('time.google.com')
cloudflare → const NtpServer
const NtpServer('time.cloudflare.com')
facebook → const NtpServer
const NtpServer('time.facebook.com')
microsoft → const NtpServer
const NtpServer('time.windows.com')
apple → const NtpServer
const NtpServer('time.apple.com')
nist → const NtpServer
const NtpServer('time.nist.gov')
pool → const NtpServer
const NtpServer('pool.ntp.org')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
The URL of the NTP server.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NtpServer>
A constant List of the values in this enum, in order of their declaration.