parseResponse property
A function to parse the response from the API endpoint (Web only).
Implementation
final DateTime Function(http.Response)? parseResponse;
A function to parse the response from the API endpoint (Web only).
final DateTime Function(http.Response)? parseResponse;