AccurateTime class

A static class to manage accurate UTC time using HTTP synchronization and local caching.

Constructors

AccurateTime()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

now({bool isUtc = false}) Future<DateTime>
Returns the current accurate time.
nowSync({bool isUtc = false}) DateTime
Returns the current accurate time synchronously.
nowToIsoString({bool isUtc = true}) Future<String>
Returns the current accurate time as an ISO 8601 string.
setSyncInterval(Duration newInterval) → void
Updates the duration used to determine when to resync the time.